@@ -23,7 +23,7 @@ use File::HomeDir;
 use File::Spec::Functions;
 
 # Main version number that the rest of the modules pick up off of.
-our $VERSION = qv("3.2.1");
+our $VERSION = qv("3.3.0");
 
 use constant DEFAULT_PROPERTIES_FILE => catfile(File::HomeDir->my_home,
     "adwords.properties");
@@ -34,7 +34,7 @@ use constant PROXY_FORMAT_STRING => "%s/api/adwords/%s/%s/%s";
 
 # Default current version used if the client is created without the version
 # parameter.
-use constant DEFAULT_VERSION => "v201409";
+use constant DEFAULT_VERSION => "v201502";
 
 # Default alternate URL that points to production servers.
 use constant DEFAULT_ALTERNATE_URL => "https://adwords.google.com";
@@ -52,10 +52,12 @@ use constant MAX_NUM_OF_REQUEST_STATS => 500;
 # Mapping of services to namespace group, required to figure out the service
 # url endpoints.
 our %SERVICE_TO_GROUP = (
-  AdExtensionOverrideService => "cm",
+  AccountLabelService => "mcm",
+  AdCustomizerFeedService => "cm",
   AdGroupAdService => "cm",
   AdGroupBidModifierService => "cm",
   AdGroupCriterionService => "cm",
+  AdGroupExtensionSettingService => "cm",
   AdGroupFeedService => "cm",
   AdGroupService => "cm",
   AdParamService => "cm",
@@ -66,13 +68,14 @@ our %SERVICE_TO_GROUP = (
   BudgetService => "cm",
   CampaignAdExtensionService => "cm",
   CampaignCriterionService => "cm",
+  CampaignExtensionSettingService => "cm",
   CampaignFeedService => "cm",
   CampaignService => "cm",
   CampaignSharedSetService => "cm",
-  CampaignTargetService => "cm",
   ConstantDataService => "cm",
   ConversionTrackerService => "cm",
   CustomerService => "mcm",
+  CustomerExtensionSettingService => "cm",
   CustomerFeedService => "cm",
   CustomerSyncService => "ch",
   DataService => "cm",
@@ -81,6 +84,7 @@ our %SERVICE_TO_GROUP = (
   FeedMappingService => "cm",
   FeedService => "cm",
   GeoLocationService => "cm",
+  LabelService => "cm",
   LocationCriterionService => "cm",
   ManagedCustomerService => "mcm",
   MediaService => "cm",
@@ -91,7 +95,6 @@ our %SERVICE_TO_GROUP = (
   SharedSetService => "cm",
   TargetingIdeaService => "o",
   TrafficEstimatorService => "o",
-  LabelService => "cm",
 );
 
 # Useful constant to translate micros to dollars and viceversa.
